<!--
SPDX-FileCopyrightText: 2025 CoreWeave, Inc.
SPDX-License-Identifier: BSD-3-Clause
SPDX-PackageName: cwsandbox-client
-->

# SWE-bench Evaluation with CWSandbox

Run SWE-bench evaluations using CWSandbox's parallel sandbox execution.

See the [SWE-bench evaluation guide](../../docs/guides/swebench.md) for setup instructions, usage examples, and troubleshooting.
